Function init_early_secondary
pub fn init_early_secondary(cpu_id: usize)Expand description
Initializes the platform at the early stage for secondary cores.
See [init_early] for details.
pub fn init_early_secondary(cpu_id: usize)Initializes the platform at the early stage for secondary cores.
See [init_early] for details.