Function init_later_secondary
pub fn init_later_secondary(cpu_id: usize)Expand description
Initializes the platform at the later stage for secondary cores.
See [init_later] for details.
pub fn init_later_secondary(cpu_id: usize)Initializes the platform at the later stage for secondary cores.
See [init_later] for details.